#!/usr/bin/python

# Test printing

import os
os.environ['LANG']='C'
srcdir = os.environ['srcdir']

from dogtail.procedural import *

run('atril', arguments=' '+srcdir+'/test-page-labels.pdf')

#!/usr/bin/python
from dogtail.procedural import *

focus.application('atril')
focus.frame('test-page-labels.pdf')
click('File', roleName='menu')
click('Print...', roleName='menu item')
focus.dialog('Print')
click('Pages:', roleName='radio button')
keyCombo('Tab')
type('1')
click('Page Setup', roleName='page tab', raw=True)
click('All sheets')
click('Even sheets')
click('Print Preview', roleName='push button')
keyCombo('Return')
click('Cancel')

# Close atril
click('File', roleName='menu')
click('Close', roleName='menu item')



#!/usr/bin/python

# This test opens the interface and just clicks around a bit.

import os
os.environ['LANG']='C'

from dogtail.procedural import *

run('atril')

# Test file->open
click('File', roleName='menu')
click('Open...', roleName='menu item')
focus.dialog('Open Document')
click('Cancel', roleName='push button')

# Toolbar editor
click('Edit', roleName='menu')
click('Toolbar', roleName='menu item')
focus.dialog('Toolbar Editor')
click('Close', roleName='push button')

# About dialog
click('Help', roleName='menu')
click('About', roleName='menu item')
focus.dialog('About Document Viewer')
click('Credits', roleName='push button')
focus.dialog('Credits')
click('Close', roleName='push button')
focus.dialog('About Document Viewer')
click('Close', roleName='push button')

# Close atril
click('File', roleName='menu')
click('Close', roleName='menu item')



#!/usr/bin/python

# Test printing

import os
os.environ['LANG']='C'
srcdir = os.environ['srcdir']
homedir = os.environ["HOME"] + "/";

from dogtail.procedural import *

if os.path.exists(homedir + "output.ps"):
    os.unlink(homedir + "output.ps")

run('atril', arguments=' '+srcdir+'/test-page-labels.pdf')

click('File', roleName='menu')
click('Print...', roleName='menu item')

focus.dialog('Print')
click('Print to File', roleName='table cell', raw=True)
click('Print', roleName='push button')

statinfo = os.stat (homedir + "output.ps")
if statinfo.st_size > 100000:
    exit(1)
os.unlink (homedir + "output.ps")

# Close atril
click('File', roleName='menu')
click('Close', roleName='menu item')
